==> cantata_2.5.3.orig.tar.gz: cantata-2.5.3/windows/thumbnailtoolbar.h <==
/*
 * Cantata
 *
 * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
 *
 * ----
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef WINTHUMBNAILTOOLBAR_H
#define WINTHUMBNAILTOOLBAR_H

#include <QWinThumbnailToolBar>
#include <QPointer>
#include "mpd-interface/song.h"
#include "mpd-interface/mpdstatus.h"

class QWinThumbnailToolButton;
class Action;
class ThumbnailToolBar : public QWinThumbnailToolBar
{
public:
    ThumbnailToolBar(QWidget *w);
    virtual ~ThumbnailToolBar() { }

    void readSettings();
    void updateCurrentSong(const Song &song);
    void updateStatus(MPDStatus * const status);

private:
    void update();
    QWinThumbnailToolButton * createButton(Action *act);

private:
    Song currentSong;
    QPointer<MPDStatus> status;
    QWinThumbnailToolButton *prevButton;
    QWinThumbnailToolButton *playPauseButton;
    QWinThumbnailToolButton *stopButton;
    QWinThumbnailToolButton *nextButton;
};

#endif

==> cantata-3.3.0.tar.gz: cantata-3.3.0/windows/thumbnailtoolbar.h <==
/*
 * Cantata
 *
 * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
 *
 * ----
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef WINTHUMBNAILTOOLBAR_H
#define WINTHUMBNAILTOOLBAR_H

#include "mpd-interface/mpdstatus.h"
#include "mpd-interface/song.h"
#include <QPointer>
#include <QWinThumbnailToolBar>

class QWinThumbnailToolButton;
class Action;
class ThumbnailToolBar : public QWinThumbnailToolBar {
public:
	ThumbnailToolBar(QWidget* w);
	virtual ~ThumbnailToolBar() {}

	void readSettings();
	void updateCurrentSong(const Song& song);
	void updateStatus(MPDStatus* const status);

private:
	void update();
	QWinThumbnailToolButton* createButton(Action* act);

private:
	Song currentSong;
	QPointer<MPDStatus> status;
	QWinThumbnailToolButton* prevButton;
	QWinThumbnailToolButton* playPauseButton;
	QWinThumbnailToolButton* stopButton;
	QWinThumbnailToolButton* nextButton;
};

#endif
